![Asserto](.github/images/logo.png)

# Todo: Badges

### Asserto

Python assertions made fluent and easy.

    - Chained and fluent assertions.
    - Soft & Hard assertions.
    - Rich diffs for easily identifying mistakes quickly.
    - Extensibility, add your own easily.
    - More...

Asserto is current in its early development stages; contributions are extremely welcome!
Check out our `CONTRIBUTING.md` to get started.
